==> nezha-engine-api-1.2.12-20240305.024431-1-sources.jar: cn/com/duiba/nezha/engine/api/dto/ReqAdvertNewDto.java <==
package cn.com.duiba.nezha.engine.api.dto;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

/**
 * Created by lwj on 16/8/2. <br/>
 * 广告结果集
 */
public class ReqAdvertNewDto implements Serializable {

    private static final long serialVersionUID = 523827427472072954L;

    /**
     * 用户参数
     */
    private ConsumerDto consumerDto;

    /**
     * 广告列表
     */
    private List<AdvertNewDto> advertList;

    /**
     * 请求参数
     */
    private RequestDto requestDto;

    /**
     * app参数
     */
    private AppDto appDto;

    /**
     * 扩展参数
     */
    @Deprecated
    private CustomExtDto customExtDto;

    /**
     * 活动参数
     */
    private AdvertActivityDto advertActivityDto;
    /**
     * 活动特征
     */
    private ActivityFeatureDTO activityFeatureDTO;
    /**
     * 策略测试
     */
    private Map<Long, String> strategyAbTestMap;

    private Integer preCalibrateTestId;

    public Integer getPreCalibrateTestId() {
        return preCalibrateTestId;
    }

    public void setPreCalibrateTestId(Integer preCalibrateTestId) {
        this.preCalibrateTestId = preCalibrateTestId;
    }

    public Map<Long, String> getStrategyAbTestMap() {
        return strategyAbTestMap;
    }

    public void setStrategyAbTestMap(Map<Long, String> strategyAbTestMap) {
        this.strategyAbTestMap = strategyAbTestMap;
    }

    public ActivityFeatureDTO getActivityFeatureDTO() {
        return activityFeatureDTO;
    }

    public void setActivityFeatureDTO(ActivityFeatureDTO activityFeatureDTO) {
        this.activityFeatureDTO = activityFeatureDTO;
    }

    /**
     * 活动预发券所需要的广告数
     */
    private Integer returnAdvertSum;

    public ReqAdvertNewDto() {
        consumerDto = new ConsumerDto();
        requestDto = new RequestDto();
        appDto = new AppDto();
        advertActivityDto = new AdvertActivityDto();
        customExtDto = new CustomExtDto();
    }


    public ConsumerDto getConsumerDto() {
        return consumerDto;
    }

    public ReqAdvertNewDto setConsumerDto(ConsumerDto consumerDto) {
        this.consumerDto = consumerDto;
        return this;
    }

    public List<AdvertNewDto> getAdvertList() {
        return advertList;
    }

    public ReqAdvertNewDto setAdvertList(List<AdvertNewDto> advertList) {
        this.advertList = advertList;
        return this;
    }

    public RequestDto getRequestDto() {
        return requestDto;
    }

    public ReqAdvertNewDto setRequestDto(RequestDto requestDto) {
        this.requestDto = requestDto;
        return this;
    }

    public AppDto getAppDto() {
        return appDto;
    }

    public ReqAdvertNewDto setAppDto(AppDto appDto) {
        this.appDto = appDto;
        return this;
    }

    public AdvertActivityDto getAdvertActivityDto() {
        return advertActivityDto;
    }

    public ReqAdvertNewDto setAdvertActivityDto(AdvertActivityDto advertActivityDto) {
        this.advertActivityDto = advertActivityDto;
        return this;
    }

    public Integer getReturnAdvertSum() {
        return returnAdvertSum;
    }

    public void setReturnAdvertSum(Integer returnAdvertSum) {
        this.returnAdvertSum = returnAdvertSum;
    }

    public CustomExtDto getCustomExtDto() {
        return customExtDto;
    }

    public void setCustomExtDto(CustomExtDto customExtDto) {
        this.customExtDto = customExtDto;
    }
}

==> nezha-engine-api-1.2.22-sources.jar: cn/com/duiba/nezha/engine/api/dto/ReqAdvertNewDto.java <==
package cn.com.duiba.nezha.engine.api.dto;

import java.io.Serializable;
import java.util.List;
import java.util.Map;

/**
 * Created by lwj on 16/8/2. <br/>
 * 广告结果集
 */
public class ReqAdvertNewDto implements Serializable {

    private static final long serialVersionUID = 523827427472072954L;

    /**
     * 用户参数
     */
    private ConsumerDto consumerDto;

    /**
     * 广告列表
     */
    private List<AdvertNewDto> advertList;

    /**
     * 请求参数
     */
    private RequestDto requestDto;

    /**
     * app参数
     */
    private AppDto appDto;

    /**
     * 扩展参数
     */
    @Deprecated
    private CustomExtDto customExtDto;

    /**
     * 活动参数
     */
    private AdvertActivityDto advertActivityDto;
    /**
     * 活动特征
     */
    private ActivityFeatureDTO activityFeatureDTO;
    /**
     * 策略测试
     */
    private Map<Long, String> strategyAbTestMap;

    private Integer preCalibrateTestId;
    /**
     * 货到行业 消耗和利润abtest表示 0-对照组 1-实验组 （实验组需要加权）
     */
    private Integer hdProfitConsumeAbtest;
    /**
     * 手机号
     */
    private String phone;
    /**
     * 广告主手机号校验abtest
     */
    private Integer advertiserPhoneCheckAbtestId;

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Integer getAdvertiserPhoneCheckAbtestId() {
        return advertiserPhoneCheckAbtestId;
    }

    public void setAdvertiserPhoneCheckAbtestId(Integer advertiserPhoneCheckAbtestId) {
        this.advertiserPhoneCheckAbtestId = advertiserPhoneCheckAbtestId;
    }

    public Integer getHdProfitConsumeAbtest() {
        return hdProfitConsumeAbtest;
    }

    public void setHdProfitConsumeAbtest(Integer hdProfitConsumeAbtest) {
        this.hdProfitConsumeAbtest = hdProfitConsumeAbtest;
    }

    public Integer getPreCalibrateTestId() {
        return preCalibrateTestId;
    }

    public void setPreCalibrateTestId(Integer preCalibrateTestId) {
        this.preCalibrateTestId = preCalibrateTestId;
    }

    public Map<Long, String> getStrategyAbTestMap() {
        return strategyAbTestMap;
    }

    public void setStrategyAbTestMap(Map<Long, String> strategyAbTestMap) {
        this.strategyAbTestMap = strategyAbTestMap;
    }

    public ActivityFeatureDTO getActivityFeatureDTO() {
        return activityFeatureDTO;
    }

    public void setActivityFeatureDTO(ActivityFeatureDTO activityFeatureDTO) {
        this.activityFeatureDTO = activityFeatureDTO;
    }

    /**
     * 活动预发券所需要的广告数
     */
    private Integer returnAdvertSum;

    public ReqAdvertNewDto() {
        consumerDto = new ConsumerDto();
        requestDto = new RequestDto();
        appDto = new AppDto();
        advertActivityDto = new AdvertActivityDto();
        customExtDto = new CustomExtDto();
    }


    public ConsumerDto getConsumerDto() {
        return consumerDto;
    }

    public ReqAdvertNewDto setConsumerDto(ConsumerDto consumerDto) {
        this.consumerDto = consumerDto;
        return this;
    }

    public List<AdvertNewDto> getAdvertList() {
        return advertList;
    }

    public ReqAdvertNewDto setAdvertList(List<AdvertNewDto> advertList) {
        this.advertList = advertList;
        return this;
    }

    public RequestDto getRequestDto() {
        return requestDto;
    }

    public ReqAdvertNewDto setRequestDto(RequestDto requestDto) {
        this.requestDto = requestDto;
        return this;
    }

    public AppDto getAppDto() {
        return appDto;
    }

    public ReqAdvertNewDto setAppDto(AppDto appDto) {
        this.appDto = appDto;
        return this;
    }

    public AdvertActivityDto getAdvertActivityDto() {
        return advertActivityDto;
    }

    public ReqAdvertNewDto setAdvertActivityDto(AdvertActivityDto advertActivityDto) {
        this.advertActivityDto = advertActivityDto;
        return this;
    }

    public Integer getReturnAdvertSum() {
        return returnAdvertSum;
    }

    public void setReturnAdvertSum(Integer returnAdvertSum) {
        this.returnAdvertSum = returnAdvertSum;
    }

    public CustomExtDto getCustomExtDto() {
        return customExtDto;
    }

    public void setCustomExtDto(CustomExtDto customExtDto) {
        this.customExtDto = customExtDto;
    }
}
